@@ -96,6 +96,14 @@ specs_dict = {
                 "example": f"{base_url}/raw/v2.0/examples/Deliberations_ok.csv",
                 "required": True,
             },
+            {
+                "name": "header_case",
+                "in": "query",
+                "type": "boolean",
+                "description": "Should validation of headers be case-sensitive",
+                "default": "true",
+                "required": False
+            }
         ],
         "produces": ["application/json"],
     },
@@ -118,6 +126,14 @@ specs_dict = {
                 "description": "The file to upload",
                 "required": True,
             },
+            {
+                "name": "header_case",
+                "in": "formData",
+                "type": "boolean",
+                "descripton": "Should validation of headers be case-sensitive",
+                "default": "true",
+                "required": False
+            }
         ],
         "consumes": ["multipart/form-data"],
         "produces": ["application/json"],
@@ -227,11 +243,13 @@ def validate():
         args = {
             "schema": request.args.get("schema"),
             "url": request.args.get("url"),
+            "header_case": request.args.get("header_case")
         }
     else:
         assert request.method == "POST", request.method
         args = {
             "schema": request.form.get("schema"),
+            "header_case": request.form.get("header_case")
         }
 
     if not args["schema"]:
@@ -270,7 +288,11 @@ def validate():
         }
         return make_json_response(body, args)
 
-    validation_report = validata_core.validate([header] + rows, schema_dict)
+    if args['header_case'] is None:
+        header_case = True
+    else:
+        header_case = args['header_case'].lower() == 'true'
+    validation_report = validata_core.validate([header] + rows, schema_dict, header_case)
 
     body = {
         "report": validation_report.to_dict(),
